tonalitytools.Scale
===================

.. abjad-lineage:: abjad.tools.tonalitytools.Scale.Scale.Scale

.. autoclass:: abjad.tools.tonalitytools.Scale.Scale.Scale
   :noindex:

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.tonalitytools.Scale.Scale.Scale.diatonic_interval_class_segment
   :noindex:

.. autoattribute:: abjad.tools.tonalitytools.Scale.Scale.Scale.dominant
   :noindex:

.. autoattribute:: abjad.tools.tonalitytools.Scale.Scale.Scale.inversion_equivalent_diatonic_interval_class_segment
   :noindex:

.. autoattribute:: abjad.tools.tonalitytools.Scale.Scale.Scale.key_signature
   :noindex:

.. autoattribute:: abjad.tools.tonalitytools.Scale.Scale.Scale.leading_tone
   :noindex:

.. autoattribute:: abjad.tools.tonalitytools.Scale.Scale.Scale.mediant
   :noindex:

.. autoattribute:: abjad.tools.tonalitytools.Scale.Scale.Scale.named_chromatic_pitch_class_set
   :noindex:

.. autoattribute:: abjad.tools.tonalitytools.Scale.Scale.Scale.named_chromatic_pitch_classes
   :noindex:

.. autoattribute:: abjad.tools.tonalitytools.Scale.Scale.Scale.numbered_chromatic_pitch_class_segment
   :noindex:

.. autoattribute:: abjad.tools.tonalitytools.Scale.Scale.Scale.numbered_chromatic_pitch_class_set
   :noindex:

.. autoattribute:: abjad.tools.tonalitytools.Scale.Scale.Scale.numbered_chromatic_pitch_classes
   :noindex:

.. autoattribute:: abjad.tools.tonalitytools.Scale.Scale.Scale.storage_format
   :noindex:

.. autoattribute:: abjad.tools.tonalitytools.Scale.Scale.Scale.subdominant
   :noindex:

.. autoattribute:: abjad.tools.tonalitytools.Scale.Scale.Scale.submediant
   :noindex:

.. autoattribute:: abjad.tools.tonalitytools.Scale.Scale.Scale.superdominant
   :noindex:

.. autoattribute:: abjad.tools.tonalitytools.Scale.Scale.Scale.tonic
   :noindex:

Methods
-------

.. automethod:: abjad.tools.tonalitytools.Scale.Scale.Scale.count
   :noindex:

.. automethod:: abjad.tools.tonalitytools.Scale.Scale.Scale.create_named_chromatic_pitch_set_in_pitch_range
   :noindex:

.. automethod:: abjad.tools.tonalitytools.Scale.Scale.Scale.index
   :noindex:

.. automethod:: abjad.tools.tonalitytools.Scale.Scale.Scale.is_equivalent_under_transposition
   :noindex:

.. automethod:: abjad.tools.tonalitytools.Scale.Scale.Scale.named_chromatic_pitch_class_to_scale_degree
   :noindex:

.. automethod:: abjad.tools.tonalitytools.Scale.Scale.Scale.retrograde
   :noindex:

.. automethod:: abjad.tools.tonalitytools.Scale.Scale.Scale.rotate
   :noindex:

.. automethod:: abjad.tools.tonalitytools.Scale.Scale.Scale.scale_degree_to_named_chromatic_pitch_class
   :noindex:

.. automethod:: abjad.tools.tonalitytools.Scale.Scale.Scale.transpose
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.tonalitytools.Scale.Scale.Scale.__add__
   :noindex:

.. automethod:: abjad.tools.tonalitytools.Scale.Scale.Scale.__contains__
   :noindex:

.. automethod:: abjad.tools.tonalitytools.Scale.Scale.Scale.__eq__
   :noindex:

.. automethod:: abjad.tools.tonalitytools.Scale.Scale.Scale.__ge__
   :noindex:

.. automethod:: abjad.tools.tonalitytools.Scale.Scale.Scale.__getitem__
   :noindex:

.. automethod:: abjad.tools.tonalitytools.Scale.Scale.Scale.__getslice__
   :noindex:

.. automethod:: abjad.tools.tonalitytools.Scale.Scale.Scale.__gt__
   :noindex:

.. automethod:: abjad.tools.tonalitytools.Scale.Scale.Scale.__hash__
   :noindex:

.. automethod:: abjad.tools.tonalitytools.Scale.Scale.Scale.__iter__
   :noindex:

.. automethod:: abjad.tools.tonalitytools.Scale.Scale.Scale.__le__
   :noindex:

.. automethod:: abjad.tools.tonalitytools.Scale.Scale.Scale.__len__
   :noindex:

.. automethod:: abjad.tools.tonalitytools.Scale.Scale.Scale.__lt__
   :noindex:

.. automethod:: abjad.tools.tonalitytools.Scale.Scale.Scale.__mul__
   :noindex:

.. automethod:: abjad.tools.tonalitytools.Scale.Scale.Scale.__ne__
   :noindex:

.. automethod:: abjad.tools.tonalitytools.Scale.Scale.Scale.__repr__
   :noindex:

.. automethod:: abjad.tools.tonalitytools.Scale.Scale.Scale.__rmul__
   :noindex:

.. automethod:: abjad.tools.tonalitytools.Scale.Scale.Scale.__str__
   :noindex:
